# wedgedriver [![Build Status](https://travis-ci.org/pietroferretti/ctftools.svg?branch=master)](https://travis-ci.org/pietroferretti/ctftools) [![Coverage Status](https://coveralls.io/repos/github/pietroferretti/ctftools/badge.svg?branch=master)](https://coveralls.io/github/pietroferretti/ctftools?branch=master) [![pypi](https://img.shields.io/pypi/v/ctftools.svg?style=flat)](https://pypi.org/project/ctftools/) ![Python versions](https://img.shields.io/pypi/pyversions/ctftools.svg?style=flat)

`wedgedriver` drives wedges in insecure cryptography schemes.

All the tools are licensed under the MIT License.

## Installation

```
pip install wedgedriver
```

`wedgedriver` supports both Python 2 and 3.


## Usage
**TODO**

In the meantime, check the tests to see some examples.

As of now, the tools offer attacks on most polyalphabetic substitution ciphers, some classic attacks on AES, some simple scripts to handle RSA.

